@@ -26,7 +26,7 @@ Args:
 """
 
 
-class ASTConstructor(ProtobufParserVisitor):
+class _ASTConstructor(ProtobufParserVisitor):
     def visitFile(self, ctx: ProtobufParser.FileContext):
         syntax = (
             self._getText(ctx.syntaxDecl().syntaxLevel()) if ctx.syntaxDecl() else None
@@ -50,7 +50,7 @@ class ASTConstructor(ProtobufParserVisitor):
         return ast.Import(name=name, weak=weak, public=public)
 
     def visitOptionDecl(self, ctx: ProtobufParser.OptionDeclContext):
-        name = ASTConstructor.normalize_option_name(self._getText(ctx.optionName()))
+        name = _ASTConstructor.normalize_option_name(self._getText(ctx.optionName()))
         value = self.visit(ctx.optionValue())
         return ast.Option(name=name, value=value)
 
@@ -128,8 +128,8 @@ class ASTConstructor(ProtobufParserVisitor):
         )
 
     def visitCompactOption(self, ctx: ProtobufParser.CompactOptionContext):
-        name = self._getText(ctx.optionName())
-        value = self._stringToType(self._getText(ctx.optionValue()))
+        name = _ASTConstructor.normalize_option_name(self._getText(ctx.optionName()))
+        value = self.visit(ctx.optionValue())
         return ast.Option(name=name, value=value)
 
     def visitCompactOptions(self, ctx: ProtobufParser.CompactOptionsContext):
@@ -347,7 +347,7 @@ class ASTConstructor(ProtobufParserVisitor):
 
     def visitAlwaysIdent(self, ctx: ProtobufParser.AlwaysIdentContext):
         if ctx.IDENTIFIER():
-            # Unlike string/int/float, bools are just reated as identiifers in
+            # Unlike string/int/float, bools are just treated as identifiers in
             # the lexer, so we need to handle them here
             identifier_text = self._getText(ctx)
             if identifier_text in ["true", "false"]:
@@ -369,7 +369,12 @@ class ASTConstructor(ProtobufParserVisitor):
             ctx.stop.stop,
         )  # pyright: ignore [reportGeneralTypeIssues]
         text = input_stream.getText(start, stop)
-        text = text.strip('"') if strip_quotes else text
+        if (
+            strip_quotes
+            and (text.startswith('"') and text.endswith('"'))
+            or (text.startswith("'") and text.endswith("'"))
+        ):
+            text = text[1:-1]
         return text
 
     def _stringToType(self, value: str):
@@ -427,16 +432,39 @@ class ASTConstructor(ProtobufParserVisitor):
 
 
 class Parser:
+    """
+    Parser class that takes a string representing a protobuf schema and returns an
+    abstract syntax tree (AST).
+    """
+
     def __init__(
         self,
         *,
         setup_lexer: Optional[SetupLexerCb] = None,
         setup_parser: Optional[SetupParserCb] = None,
     ) -> None:
+        """
+        Initializes a new instance of the Parser class.
+
+        Args:
+            setup_lexer (Optional[SetupLexerCb], optional): A callback function to
+                modify the lexer during parsing. Defaults to None.
+            setup_parser (Optional[SetupParserCb], optional): A callback function
+                to modify the parser during parsing. Defaults to None.
+        """
         self.setup_lexer = setup_lexer
         self.setup_parser = setup_parser
 
     def parse(self, text: str) -> ast.File:
+        """
+        Parses a string representing a protobuf schema and returns an abstract syntax tree (AST).
+
+        Args:
+            text (str): The string representing the protobuf schema.
+
+        Returns:
+            ast.File: The abstract syntax tree representation of the protobuf schema.
+        """
         input_stream = InputStream(text)
         lexer = ProtobufLexer(input_stream)
         if self.setup_lexer:
@@ -448,5 +476,5 @@ class Parser:
             self.setup_parser(parser)
 
         parse_tree = parser.file_()
-        visitor = ASTConstructor()
+        visitor = _ASTConstructor()
         return visitor.visit(parse_tree)  # pyright: ignore [reportGeneralTypeIssues]
