@@ -1,7 +1,7 @@
 import pytest
 
 from proto_schema_parser import ast
-from proto_schema_parser.parser import ASTConstructor, Parser
+from proto_schema_parser.parser import Parser, _ASTConstructor
 
 
 def test_parse_person():
@@ -98,7 +98,11 @@ def test_parse_person():
                                 number=2,
                                 cardinality=ast.FieldCardinality.OPTIONAL,
                                 type="PhoneType",
-                                options=[ast.Option(name="default", value="HOME")],
+                                options=[
+                                    ast.Option(
+                                        name="default", value=ast.Identifier("HOME")
+                                    )
+                                ],
                             ),
                         ],
                     ),
@@ -142,7 +146,12 @@ def test_parse_search_request():
                         options=[
                             ast.Option(
                                 name="(validate.rules).double",
-                                value="{gte: -90,  lte: 90}",
+                                value=ast.MessageLiteral(
+                                    fields=[
+                                        ast.MessageLiteralField(name="gte", value=-90),
+                                        ast.MessageLiteralField(name="lte", value=90),
+                                    ]
+                                ),
                             )
                         ],
                     ),
@@ -1440,59 +1449,59 @@ def test_option_with_comments_and_fields():
 
 
 def test_normalize_option_name_simple():
-    assert ASTConstructor.normalize_option_name("option_name") == "option_name"
+    assert _ASTConstructor.normalize_option_name("option_name") == "option_name"
 
 
 def test_normalize_option_name_with_spaces():
-    assert ASTConstructor.normalize_option_name(" option . name ") == "option.name"
+    assert _ASTConstructor.normalize_option_name(" option . name ") == "option.name"
 
 
 def test_normalize_option_name_with_parentheses():
     assert (
-        ASTConstructor.normalize_option_name(" ( option_name ) . field ")
+        _ASTConstructor.normalize_option_name(" ( option_name ) . field ")
         == "(option_name).field"
     )
 
 
 def test_normalize_option_name_nested_parentheses():
     assert (
-        ASTConstructor.normalize_option_name(" ( ( nested ) . option ) . field ")
+        _ASTConstructor.normalize_option_name(" ( ( nested ) . option ) . field ")
         == "(nested.option).field"
     )
 
 
 def test_normalize_option_name_no_space_parentheses():
     assert (
-        ASTConstructor.normalize_option_name("(option_name).field")
+        _ASTConstructor.normalize_option_name("(option_name).field")
         == "(option_name).field"
     )
 
 
 def test_normalize_option_name_mixed_case():
     assert (
-        ASTConstructor.normalize_option_name("(Option_Name).Field")
+        _ASTConstructor.normalize_option_name("(Option_Name).Field")
         == "(Option_Name).Field"
     )
 
 
 def test_normalize_option_name_with_extra_parentheses():
     assert (
-        ASTConstructor.normalize_option_name("( ( validate.rules ) ).double")
+        _ASTConstructor.normalize_option_name("( ( validate.rules ) ).double")
         == "(validate.rules).double"
     )
 
 
 def test_normalize_option_name_empty():
-    assert ASTConstructor.normalize_option_name("") == ""
+    assert _ASTConstructor.normalize_option_name("") == ""
 
 
 def test_normalize_option_name_only_parentheses():
-    assert ASTConstructor.normalize_option_name("(( ))") == "()"
+    assert _ASTConstructor.normalize_option_name("(( ))") == "()"
 
 
 def test_normalize_option_name_with_symbols():
     assert (
-        ASTConstructor.normalize_option_name("(validate.rules).$double_value")
+        _ASTConstructor.normalize_option_name("(validate.rules).$double_value")
         == "(validate.rules).$double_value"
     )
 
@@ -1691,3 +1700,142 @@ def test_syntax_error():
         exc_info.value.args[0]
         == r"Failed to parse: line 6:4: mismatched input '}' expecting {';', '['}"
     )
+
+
+def test_parse_complex_compact_option():
+    text_with_email = """
+    syntax = "proto3";
+
+    message Foo {
+      string bar = 4 [
+        (oompa.loompa) = {
+          example: "mini@mouse.com";
+        }
+      ];
+    }
+    """
+
+    result = Parser().parse(text_with_email)
+    expected = ast.File(
+        syntax="proto3",
+        file_elements=[
+            ast.Message(
+                name="Foo",
+                elements=[
+                    ast.Field(
+                        name="bar",
+                        number=4,
+                        type="string",
+                        options=[
+                            ast.Option(
+                                name="(oompa.loompa)",
+                                value=ast.MessageLiteral(
+                                    fields=[
+                                        ast.MessageLiteralField(
+                                            name="example",
+                                            value="mini@mouse.com",
+                                        )
+                                    ]
+                                ),
+                            )
+                        ],
+                    ),
+                ],
+            ),
+        ],
+    )
+    assert result == expected
+
+
+def test_parse_complex_compact_option_with_escaped_string():
+    text_with_email = """
+    syntax = "proto3";
+
+    message Foo {
+      string bar = 4 [
+        (oompa.loompa) = {
+          example: "\\"blah\\"";
+        }
+      ];
+    }
+    """
+
+    print(text_with_email)
+
+    result = Parser().parse(text_with_email)
+    expected = ast.File(
+        syntax="proto3",
+        file_elements=[
+            ast.Message(
+                name="Foo",
+                elements=[
+                    ast.Field(
+                        name="bar",
+                        number=4,
+                        type="string",
+                        options=[
+                            ast.Option(
+                                name="(oompa.loompa)",
+                                value=ast.MessageLiteral(
+                                    fields=[
+                                        ast.MessageLiteralField(
+                                            name="example",
+                                            value='\\"blah\\"',
+                                        )
+                                    ]
+                                ),
+                            )
+                        ],
+                    ),
+                ],
+            ),
+        ],
+    )
+    assert result == expected
+
+
+def test_parse_email_compact_option_with_escaped_string():
+    text_with_email = """
+    syntax = "proto3";
+
+    message Foo {
+      string bar = 4 [
+        (oompa.loompa) = {
+          example: "\\"mini@mouse.com\\"";
+        }
+      ];
+    }
+    """
+
+    print(text_with_email)
+
+    result = Parser().parse(text_with_email)
+    expected = ast.File(
+        syntax="proto3",
+        file_elements=[
+            ast.Message(
+                name="Foo",
+                elements=[
+                    ast.Field(
+                        name="bar",
+                        number=4,
+                        type="string",
+                        options=[
+                            ast.Option(
+                                name="(oompa.loompa)",
+                                value=ast.MessageLiteral(
+                                    fields=[
+                                        ast.MessageLiteralField(
+                                            name="example",
+                                            value='\\"mini@mouse.com\\"',
+                                        )
+                                    ]
+                                ),
+                            )
+                        ],
+                    ),
+                ],
+            ),
+        ],
+    )
+    assert result == expected
